Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSchemaConfigContext ¶
func NewSchemaConfigContext(parent context.Context, config SchemaConfig) context.Context
NewSchemaConfigContext returns a new context with the given SchemaConfig attached.
Types ¶
type SchemaConfig ¶
type SchemaConfig struct {
Catalog string // Catalog table.
Connector string // Connector table.
CostReport string // CostReport table.
DistributeLock string // DistributeLock table.
Environment string // Environment table.
EnvironmentConnectorRelationship string // EnvironmentConnectorRelationship table.
Perspective string // Perspective table.
Project string // Project table.
Resource string // Resource table.
ResourceComponent string // ResourceComponent table.
ResourceComponentRelationship string // ResourceComponentRelationship table.
ResourceDefinition string // ResourceDefinition table.
ResourceDefinitionMatchingRule string // ResourceDefinitionMatchingRule table.
ResourceRelationship string // ResourceRelationship table.
ResourceRevision string // ResourceRevision table.
Role string // Role table.
Setting string // Setting table.
Subject string // Subject table.
SubjectRoleRelationship string // SubjectRoleRelationship table.
Template string // Template table.
TemplateVersion string // TemplateVersion table.
Token string // Token table.
Variable string // Variable table.
Workflow string // Workflow table.
WorkflowExecution string // WorkflowExecution table.
WorkflowStage string // WorkflowStage table.
WorkflowStageExecution string // WorkflowStageExecution table.
WorkflowStep string // WorkflowStep table.
WorkflowStepExecution string // WorkflowStepExecution table.
}
SchemaConfig represents alternative schema names for all tables that can be passed at runtime.
func SchemaConfigFromContext ¶
func SchemaConfigFromContext(ctx context.Context) SchemaConfig
SchemaConfigFromContext returns a SchemaConfig stored inside a context, or empty if there isn't one.
Click to show internal directories.
Click to hide internal directories.